@@ -48,7 +48,15 @@ use File::Spec ();
 # Globals
 use vars qw{$VERSION $RE_IDENTIFIER $RE_CLASS $UNIX};
 BEGIN {
-	$VERSION = '1.20';
+	$VERSION = '1.22';
+
+	# If Unicode is available, enable it so that the
+	# pattern matches below match unicode method names.
+	# We can safely ignore any failure here.
+	eval {
+		require utf8;
+		utf8->import;
+	};
 
 	# Predefine some regexs
 	$RE_IDENTIFIER = qr/\A[^\W\d]\w*\z/s;
@@ -620,7 +628,7 @@ L<http://ali.as/>, L<Class::Handle>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002 - 2006 Adam Kennedy.
+Copyright 2002 - 2008 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
